@@ -5,24 +5,21 @@
 #'
 #' @param sim a matrix of simulated variables that have been interpolated
 #' @param obs observed values of variable.
-#' @param file_name the file path to save the generated contour figure.
+#' @param file.name the file path to save the generated contour figure.
 #' @param sim.start,sim.end the start and end of the simulation period for the DYRESM-CAEDYM model run of interest. The date format must be "\%Y-\%m-\%d".
 #' @param plot.start,plot.end the start and end of the plot period, in the format of "\%Y-\%m-\%d"
 #' @param legend.title the legend title of the contour figure.
 #' @param min.depth,max.depth,by.value minimum and maximum depth used to be the start of y axis of the contour plot, at the increment of by.value.
 #' @param nlevels a set of levels which are used to partition the range of simulation variable.
-#' @param height,width the relative height/width of the figure.
-#' @param ppi the ppi value of the figure.
-#' @param plot.save if TRUE, the plot is saved with the "height","width", and "ppi" parameters.
 #'
 #' @importFrom grDevices hcl.colors png dev.off
 #' @importFrom graphics axis filled.contour mtext par points title
 #' @importFrom lubridate year
-#' @return a graph file of contour plot saved in the Figure folder.
+#' @return This function returns a filled.contour object.
 #'
 #' @examples
 #' # extract simulated temperature values from DYRESM-CAEDYM simulation file
-#'  var.values<-ext.output(dycd.output=system.file("extdata", "dysim.nc", package = "dycdtools"),
+#'  var.values<-ext_output(dycd.output=system.file("extdata", "dysim.nc", package = "dycdtools"),
 #'                        var.extract=c("TEMP"))
 #'
 #'   for(i in 1:length(var.values)){
@@ -37,7 +34,7 @@
 #'
 #'   data(obs_temp)
 #' # contour plot of temperature simulations with observed data shown as colour-coded dots
-#'   plot_cont_comp(sim=temp.interpolated,
+#'   p <- plot_cont_comp(sim=temp.interpolated,
 #'                  obs=obs_temp,
 #'                  sim.start = "2017-06-06",
 #'                  sim.end = "2017-06-15",
@@ -45,25 +42,24 @@
 #'                  plot.end="2017-06-15",
 #'                  legend.title="T \u00B0C",
 #'                  min.depth=0,max.depth=13,by.value=0.5,
-#'                  nlevels=20,
-#'                  plot.save=FALSE,
-#'                  file_name="Contour_temp.png",
-#'                  height=5,width=8,ppi=150)
+#'                  nlevels=20)
+#'
+#'  p
 #'
 #' @export
 
-plot_cont_comp<-function(sim=temp.interpolated,
-                         obs=obs_temp,
-                         file_name="Contour_temp.png",
-                         sim.start = "2002-01-23",
-                         sim.end = "2016-12-31",
-                         plot.start="2017-06-06",
-                         plot.end="2017-06-15",
-                         legend.title="T \u00B0C",
-                         min.depth=0,max.depth=13,by.value=0.5,
-                         nlevels=20,
-                         plot.save=TRUE,
-                         height=5,width=8,ppi=150){
+plot_cont_comp<-function(sim,
+                         obs,
+                         file.name,
+                         sim.start,
+                         sim.end,
+                         plot.start,
+                         plot.end,
+                         legend.title,
+                         min.depth,
+                         max.depth,
+                         by.value,
+                         nlevels){
 
   #---
   # 1. simulation period
@@ -93,11 +89,8 @@ plot_cont_comp<-function(sim=temp.interpolated,
   #---
   # 2. contour plot the var matrix
   #---
-  if(plot.save){
-    png(filename = file_name,height = height*ppi,width = width*ppi)
-  }
 
-  filled.contour(x=seq(1,ncol(plot.sim),by=1),
+  p <- filled.contour(x=seq(1,ncol(plot.sim),by=1),
                  y=seq(min.depth,max.depth,by=by.value),
                  z=t(plot.sim),
                  ylim = c(max.depth,min.depth),
@@ -113,7 +106,7 @@ plot_cont_comp<-function(sim=temp.interpolated,
                  key.title = {
                    par(cex.main=1.3); title(main=legend.title)
                  })
-  if(plot.save){
-    dev.off()
-  }
+
+  return(p)
+
 }
