@@ -2,9 +2,8 @@
 #' @param extract_val a vector.
 #'
 
-delete.space<-function(extract_val){
-  while(extract_val[1]=="")
-  {
+delete_space <- function(extract_val){
+  while(extract_val[1] == ""){
     extract_val<-extract_val[-1]
   }
   return(extract_val)
